Sizer class final

Annotations

Constructors

Sizer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSp(num sp) double
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

init({required Widget child}) Widget
radius(num r) double
setHeight(num height) double
setHorizontalSpacing(num width) Widget
setHorizontalSpacingRadius(num width) Widget
setVerticalSpacing(num height) Widget
setVerticalSpacingRadius(num height) Widget
setWidth(num width) double